@@ -51,7 +51,7 @@ G_BEGIN_DECLS
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* BOOLEAN:BOXED (../../lib/ephy-marshal.list:1) */
+/* BOOLEAN:BOXED (./ephy-marshal.list:1) */
 extern void ephy_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -96,7 +96,7 @@ ephy_marshal_BOOLEAN__BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:ENUM,STRING,STRING,STRING (../../lib/ephy-marshal.list:2) */
+/* BOOLEAN:ENUM,STRING,STRING,STRING (./ephy-marshal.list:2) */
 extern void ephy_marshal_BOOLEAN__ENUM_STRING_STRING_STRING (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
@@ -147,7 +147,7 @@ ephy_marshal_BOOLEAN__ENUM_STRING_STRING_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT (../../lib/ephy-marshal.list:3) */
+/* BOOLEAN:OBJECT (./ephy-marshal.list:3) */
 extern void ephy_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -192,7 +192,52 @@ ephy_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,STRING (../../lib/ephy-marshal.list:4) */
+/* BOOLEAN:STRING (./ephy-marshal.list:4) */
+extern void ephy_marshal_BOOLEAN__STRING (GClosure     *closure,
+                                          GValue       *return_value,
+                                          guint         n_param_values,
+                                          const GValue *param_values,
+                                          gpointer      invocation_hint,
+                                          gpointer      marshal_data);
+void
+ephy_marshal_BOOLEAN__STRING (GClosure     *closure,
+                              GValue       *return_value,
+                              guint         n_param_values,
+                              const GValue *param_values,
+                              gpointer      invocation_hint,
+                              gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__STRING) (gpointer     data1,
+                                                    gpointer     arg_1,
+                                                    gpointer     data2);
+  register GMarshalFunc_BOOLEAN__STRING callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__STRING) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_string (param_values + 1),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* BOOLEAN:STRING,STRING (./ephy-marshal.list:5) */
 extern void ephy_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -239,7 +284,7 @@ ephy_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,STRING,STRING (../../lib/ephy-marshal.list:5) */
+/* BOOLEAN:STRING,STRING,STRING (./ephy-marshal.list:6) */
 extern void ephy_marshal_BOOLEAN__STRING_STRING_STRING (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -288,7 +333,7 @@ ephy_marshal_BOOLEAN__STRING_STRING_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:VOID (../../lib/ephy-marshal.list:6) */
+/* BOOLEAN:VOID (./ephy-marshal.list:7) */
 extern void ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -331,7 +376,7 @@ ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* OBJECT:OBJECT,FLAGS (../../lib/ephy-marshal.list:7) */
+/* OBJECT:OBJECT,FLAGS (./ephy-marshal.list:8) */
 extern void ephy_marshal_OBJECT__OBJECT_FLAGS (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -378,7 +423,7 @@ ephy_marshal_OBJECT__OBJECT_FLAGS (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* OBJECT:STRING,OBJECT,FLAGS (../../lib/ephy-marshal.list:8) */
+/* OBJECT:STRING,OBJECT,FLAGS (./ephy-marshal.list:9) */
 extern void ephy_marshal_OBJECT__STRING_OBJECT_FLAGS (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -427,7 +472,7 @@ ephy_marshal_OBJECT__STRING_OBJECT_FLAGS (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* STRING:STRING,STRING (../../lib/ephy-marshal.list:9) */
+/* STRING:STRING,STRING (./ephy-marshal.list:10) */
 extern void ephy_marshal_STRING__STRING_STRING (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -474,7 +519,7 @@ ephy_marshal_STRING__STRING_STRING (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
-/* STRING:VOID (../../lib/ephy-marshal.list:10) */
+/* STRING:VOID (./ephy-marshal.list:11) */
 extern void ephy_marshal_STRING__VOID (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -517,10 +562,10 @@ ephy_marshal_STRING__VOID (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
-/* VOID:ENUM (../../lib/ephy-marshal.list:11) */
+/* VOID:ENUM (./ephy-marshal.list:12) */
 #define ephy_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM
 
-/* VOID:POINTER,BOOLEAN (../../lib/ephy-marshal.list:12) */
+/* VOID:POINTER,BOOLEAN (./ephy-marshal.list:13) */
 extern void ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -563,7 +608,7 @@ ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER (../../lib/ephy-marshal.list:13) */
+/* VOID:POINTER,POINTER (./ephy-marshal.list:14) */
 extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -606,7 +651,7 @@ ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,FLAGS (../../lib/ephy-marshal.list:14) */
+/* VOID:STRING,FLAGS (./ephy-marshal.list:15) */
 extern void ephy_marshal_VOID__STRING_FLAGS (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -649,7 +694,7 @@ ephy_marshal_VOID__STRING_FLAGS (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT (../../lib/ephy-marshal.list:15) */
+/* VOID:STRING,INT (./ephy-marshal.list:16) */
 extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -692,7 +737,7 @@ ephy_marshal_VOID__STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING (../../lib/ephy-marshal.list:16) */
+/* VOID:STRING,STRING (./ephy-marshal.list:17) */
 extern void ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -735,7 +780,7 @@ ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,STRING (../../lib/ephy-marshal.list:17) */
+/* VOID:STRING,STRING,STRING (./ephy-marshal.list:18) */
 extern void ephy_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
