@@ -17,12 +17,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-state.c,v 1.30 2004/11/02 20:57:20 chpe Exp $
+ *  $Id: ephy-state.c,v 1.36.4.1 2005/10/02 22:35:02 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-state.h"
+#include "ephy-lib-type-builtins.h"
 #include "ephy-file-helpers.h"
 #include "ephy-node-db.h"
 #include "ephy-node-common.h"
@@ -33,8 +34,8 @@
 #include <gtk/gtkexpander.h>
 
 #define EPHY_STATES_XML_FILE	"states.xml"
-#define EPHY_STATES_XML_ROOT    "ephy_states"
-#define EPHY_STATES_XML_VERSION "1.0"
+#define EPHY_STATES_XML_ROOT    (const xmlChar *)"ephy_states"
+#define EPHY_STATES_XML_VERSION (const xmlChar *)"1.0"
 
 enum
 {
@@ -62,11 +63,12 @@ ephy_states_save (void)
                                      NULL);
 
 	ephy_node_db_write_to_xml_safe
-		(states_db, xml_file,
+		(states_db, 
+		 (const xmlChar *)xml_file,
 		 EPHY_STATES_XML_ROOT,
 		 EPHY_STATES_XML_VERSION,
 		 NULL, /* comment */
-		 states, 0,
+		 states, NULL, NULL,
 		 NULL);
 
 	g_free (xml_file);	
@@ -103,8 +105,12 @@ ensure_states (void)
 {
 	if (states == NULL)
 	{
+		volatile GType flags_type; /* work around gcc's optimiser */
 		char *xml_file;
 
+		/* make sure the type is known when we read the db */
+		flags_type = EPHY_TYPE_STATE_WINDOW_FLAGS;
+
 		xml_file = g_build_filename (ephy_dot_dir (),
 					     EPHY_STATES_XML_FILE,
 					     NULL);
@@ -392,15 +398,15 @@ ephy_state_add_window (GtkWidget *window,
 }
 
 static gboolean
-paned_size_allocate_cb (GtkWidget *paned,
-			GtkAllocation *allocation,
+paned_sync_position_cb (GtkWidget *paned,
+			GParamSpec *pspec,
 			EphyNode *node)
 {
 	int width;
 	GValue value = { 0, };
 
 	width = gtk_paned_get_position (GTK_PANED (paned));
-
+	
 	g_value_init (&value, G_TYPE_INT);
 	g_value_set_int (&value, width);
 	ephy_node_set_property (node, EPHY_NODE_STATE_PROP_WIDTH,
@@ -444,8 +450,8 @@ ephy_state_add_paned (GtkWidget *paned,
 	width = ephy_node_get_property_int (node, EPHY_NODE_STATE_PROP_WIDTH);
 	gtk_paned_set_position (GTK_PANED (paned), width);
 
-	g_signal_connect (paned, "size_allocate",
-			  G_CALLBACK (paned_size_allocate_cb), node);
+	g_signal_connect (paned, "notify::position",
+			  G_CALLBACK (paned_sync_position_cb), node);
 }
 
 static void
