@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.174 2005/08/08 20:19:56 chpe Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.174.4.1 2005/10/02 22:35:02 chpe Exp $
  */
 
 #include "config.h"
@@ -1684,7 +1684,7 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 					"vscrollbar_policy", GTK_POLICY_AUTOMATIC,
 					"shadow_type", GTK_SHADOW_IN,
 					NULL);
-	gtk_paned_pack1 (GTK_PANED (hpaned), GTK_WIDGET (scrolled_window), TRUE, TRUE);
+	gtk_paned_pack1 (GTK_PANED (hpaned), GTK_WIDGET (scrolled_window), FALSE, TRUE);
 	gtk_widget_show (scrolled_window);
 
 	/* Keywords View */
